#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-test
version:              2.13.1.3
visibility:           public
id:                   persistent-test-2.13.1.3-9RdEvsHXTg0BwLIIsgoBWa
key:                  persistent-test-2.13.1.3-9RdEvsHXTg0BwLIIsgoBWa
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.

category:             Database, Yesod
abi:                  231b8a1c11a00bb672be38c4344df8e4
exposed:              True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest ForeignKey
    GeneratedColumnTestSQL HtmlTest Init LargeNumberTest
    LongIdentifierTest MaxLenTest MaybeFieldDefsTest
    MigrationColumnLengthTest MigrationIdempotencyTest
    MigrationOnlyTest MigrationTest MpsCustomPrefixTest MpsNoPrefixTest
    PersistTestPetCollarType PersistTestPetType PersistUniqueTest
    PersistentTest PersistentTestModels PersistentTestModelsImports
    PrimaryTest RawSqlTest ReadWriteTest Recursive RenameTest
    SumTypeTest TransactionLevelTest TreeTest TypeLitFieldDefsTest
    UniqueTest UpsertTest

import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-test-2.13.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-test
hs-libraries:         HSpersistent-test-2.13.1.3-9RdEvsHXTg0BwLIIsgoBWa
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA
    QuickCheck-2.15.0.1-KbEu55Yn4v1JAMl6aurZE0
    aeson-2.2.1.0-B3EHpOrhFBKFg56QPA2Q3I base-4.18.2.1
    blaze-html-0.9.2.0-BrSAzNVQiYJEXfJmmg87r5 bytestring-0.11.5.3
    conduit-1.3.6.1-6FfN71X8NnX6xRLVW7u2GC containers-0.6.7
    exceptions-0.10.7 hspec-2.11.5-9jOU1kYubwn2Hm3KxBN8g5
    hspec-expectations-0.8.4-JRz47SURfXgGxfIuVeuxEa
    http-api-data-0.6.1-4DLSFxR866nKJGItovjPQc
    monad-control-1.0.3.1-2dUcvCkYfVy8ju8FJuDKvv
    monad-logger-0.3.42-4RWwIGh9dmMJTSOMCdY3W2 mtl-2.3.1
    path-pieces-0.2.1-ILPSumWqTsA51OyVDS7ISl
    persistent-2.14.5.2-AnYNyOpqn2b5awZPxWmcki
    quickcheck-instances-0.3.33-DxXhCuZqwiiHPwNRJzt8aY
    random-1.2.1.3-Gsn6cRa5LQY7Fg5vZFQhOU
    resourcet-1.2.6-GrVaNPG3RF7IMcvlKlmJk8 text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-base-0.4.6.1-FAMHOXpxO6vBZr799WTIBa
    unliftio-0.2.25.1-FRGz7PceS9EF7fvbKOBYVe
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq

haddock-interfaces:
    /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock

haddock-html:         /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

